//
//  AdmostSDKPlugin.m
//  admost_flutter_plugin
//
//  Created by Mehmet Karagöz on 9.12.2019.
//

#import "AdmostSDKPlugin.h"
#import "AdmostBannerFactory.h"
#import <AMRSDK/AMRSDK.h>

@implementation AdmostSDKPlugin

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    AdmostSDKPlugin *instance = [[AdmostSDKPlugin alloc] init];
    FlutterMethodChannel *defaultChannel = [FlutterMethodChannel methodChannelWithName:@"admost_flutter"
                                                                       binaryMessenger:registrar.messenger];
    [registrar addMethodCallDelegate:instance channel:defaultChannel];
    
    AdmostBannerFactory *bannerFactory = [AdmostBannerFactory bannerFactoryWithMessenger:registrar.messenger];
    [registrar registerViewFactory:bannerFactory
                            withId:@"admost_flutter/banner"];
}

- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    if (call.arguments == nil ||
        ![call.arguments isKindOfClass:[NSDictionary class]]) {
        result(FlutterMethodNotImplemented);
        return;
    }
    
    NSDictionary *parameters = (NSDictionary *)call.arguments;
    
    if (![parameters objectForKey:@"appId"]) {
        result(FlutterMethodNotImplemented);
        return;
    }
    
    if ([parameters objectForKey:@"subjectToCCPA"]) {
        NSString *stringParam = [parameters[@"subjectToCCPA"] stringValue];
        BOOL subjectToCCPA = [stringParam boolValue];
        
        [AMRSDK subjectToCCPA:subjectToCCPA];
    }
    
    if ([parameters objectForKey:@"subjectToGDPR"]) {
        NSString *stringParam = [parameters[@"subjectToGDPR"] stringValue];
        BOOL subjectToGDPR = [stringParam boolValue];
        
        [AMRSDK subjectToGDPR:subjectToGDPR];
    }
    
    if ([parameters objectForKey:@"userConsent"]) {
        NSString *stringParam = [parameters[@"userConsent"] stringValue];
        BOOL userConsent = [stringParam boolValue];
        
        [AMRSDK setUserConsent:userConsent];
    }
    
    NSString *appId = parameters[@"appId"];
    
    if ([call.method isEqualToString:@"initialize"]) {
        [AMRSDK startWithAppId:appId];
    } else if ([call.method isEqualToString:@"startTestSuite"]) {
        [AMRSDK startTestSuiteWithAppId:appId];
    } else {
        result(FlutterMethodNotImplemented);
    }
}

@end
